/****************************************************************************
** Meta object code from reading C++ file 'treeview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmenuedit-5.8.9/treeview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'treeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TreeView_t {
    QByteArrayData data[32];
    char stringdata0[336];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TreeView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TreeView_t qt_meta_stringdata_TreeView = {
    {
QT_MOC_LITERAL(0, 0, 8), // "TreeView"
QT_MOC_LITERAL(1, 9, 13), // "entrySelected"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 15), // "MenuFolderInfo*"
QT_MOC_LITERAL(4, 40, 10), // "folderInfo"
QT_MOC_LITERAL(5, 51, 14), // "MenuEntryInfo*"
QT_MOC_LITERAL(6, 66, 9), // "entryInfo"
QT_MOC_LITERAL(7, 76, 13), // "disableAction"
QT_MOC_LITERAL(8, 90, 18), // "currentDataChanged"
QT_MOC_LITERAL(9, 109, 19), // "findServiceShortcut"
QT_MOC_LITERAL(10, 129, 9), // "KShortcut"
QT_MOC_LITERAL(11, 139, 14), // "KService::Ptr&"
QT_MOC_LITERAL(12, 154, 12), // "itemSelected"
QT_MOC_LITERAL(13, 167, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(14, 184, 12), // "dropMimeData"
QT_MOC_LITERAL(15, 197, 6), // "parent"
QT_MOC_LITERAL(16, 204, 5), // "index"
QT_MOC_LITERAL(17, 210, 16), // "const QMimeData*"
QT_MOC_LITERAL(18, 227, 4), // "data"
QT_MOC_LITERAL(19, 232, 14), // "Qt::DropAction"
QT_MOC_LITERAL(20, 247, 6), // "action"
QT_MOC_LITERAL(21, 254, 10), // "newsubmenu"
QT_MOC_LITERAL(22, 265, 7), // "newitem"
QT_MOC_LITERAL(23, 273, 6), // "newsep"
QT_MOC_LITERAL(24, 280, 3), // "cut"
QT_MOC_LITERAL(25, 284, 4), // "copy"
QT_MOC_LITERAL(26, 289, 5), // "paste"
QT_MOC_LITERAL(27, 295, 3), // "del"
QT_MOC_LITERAL(28, 299, 4), // "sort"
QT_MOC_LITERAL(29, 304, 7), // "sortCmd"
QT_MOC_LITERAL(30, 312, 10), // "moveUpItem"
QT_MOC_LITERAL(31, 323, 12) // "moveDownItem"

    },
    "TreeView\0entrySelected\0\0MenuFolderInfo*\0"
    "folderInfo\0MenuEntryInfo*\0entryInfo\0"
    "disableAction\0currentDataChanged\0"
    "findServiceShortcut\0KShortcut\0"
    "KService::Ptr&\0itemSelected\0"
    "QTreeWidgetItem*\0dropMimeData\0parent\0"
    "index\0const QMimeData*\0data\0Qt::DropAction\0"
    "action\0newsubmenu\0newitem\0newsep\0cut\0"
    "copy\0paste\0del\0sort\0sortCmd\0moveUpItem\0"
    "moveDownItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TreeView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  104,    2, 0x06 /* Public */,
       1,    1,  107,    2, 0x06 /* Public */,
       7,    0,  110,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,  111,    2, 0x0a /* Public */,
       8,    1,  114,    2, 0x0a /* Public */,
       9,    2,  117,    2, 0x0a /* Public */,
      12,    1,  122,    2, 0x09 /* Protected */,
      14,    4,  125,    2, 0x09 /* Protected */,
      21,    0,  134,    2, 0x09 /* Protected */,
      22,    0,  135,    2, 0x09 /* Protected */,
      23,    0,  136,    2, 0x09 /* Protected */,
      24,    0,  137,    2, 0x09 /* Protected */,
      25,    0,  138,    2, 0x09 /* Protected */,
      26,    0,  139,    2, 0x09 /* Protected */,
      27,    0,  140,    2, 0x09 /* Protected */,
      28,    1,  141,    2, 0x09 /* Protected */,
      30,    0,  144,    2, 0x09 /* Protected */,
      31,    0,  145,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 11,    2,    2,
    QMetaType::Void, 0x80000000 | 13,    2,
    QMetaType::Bool, 0x80000000 | 13, QMetaType::Int, 0x80000000 | 17, 0x80000000 | 19,   15,   16,   18,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void TreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TreeView *_t = static_cast<TreeView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->entrySelected((*reinterpret_cast< MenuFolderInfo*(*)>(_a[1]))); break;
        case 1: _t->entrySelected((*reinterpret_cast< MenuEntryInfo*(*)>(_a[1]))); break;
        case 2: _t->disableAction(); break;
        case 3: _t->currentDataChanged((*reinterpret_cast< MenuFolderInfo*(*)>(_a[1]))); break;
        case 4: _t->currentDataChanged((*reinterpret_cast< MenuEntryInfo*(*)>(_a[1]))); break;
        case 5: _t->findServiceShortcut((*reinterpret_cast< const KShortcut(*)>(_a[1])),(*reinterpret_cast< KService::Ptr(*)>(_a[2]))); break;
        case 6: _t->itemSelected((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 7: { bool _r = _t->dropMimeData((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QMimeData*(*)>(_a[3])),(*reinterpret_cast< Qt::DropAction(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->newsubmenu(); break;
        case 9: _t->newitem(); break;
        case 10: _t->newsep(); break;
        case 11: _t->cut(); break;
        case 12: _t->copy(); break;
        case 13: _t->paste(); break;
        case 14: _t->del(); break;
        case 15: _t->sort((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 16: _t->moveUpItem(); break;
        case 17: _t->moveDownItem(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TreeView::*_t)(MenuFolderInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TreeView::entrySelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TreeView::*_t)(MenuEntryInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TreeView::entrySelected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TreeView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TreeView::disableAction)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject TreeView::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_TreeView.data,
      qt_meta_data_TreeView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TreeView.stringdata0))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int TreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void TreeView::entrySelected(MenuFolderInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void TreeView::entrySelected(MenuEntryInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void TreeView::disableAction()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
