/****************************************************************************
** Meta object code from reading C++ file 'basictab.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kmenuedit-5.8.9/basictab.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'basictab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BasicTab_t {
    QByteArrayData data[21];
    char stringdata0[300];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BasicTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BasicTab_t qt_meta_stringdata_BasicTab = {
    {
QT_MOC_LITERAL(0, 0, 8), // "BasicTab"
QT_MOC_LITERAL(1, 9, 7), // "changed"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 15), // "MenuFolderInfo*"
QT_MOC_LITERAL(4, 34, 14), // "MenuEntryInfo*"
QT_MOC_LITERAL(5, 49, 19), // "findServiceShortcut"
QT_MOC_LITERAL(6, 69, 9), // "KShortcut"
QT_MOC_LITERAL(7, 79, 14), // "KService::Ptr&"
QT_MOC_LITERAL(8, 94, 13), // "setFolderInfo"
QT_MOC_LITERAL(9, 108, 10), // "folderInfo"
QT_MOC_LITERAL(10, 119, 12), // "setEntryInfo"
QT_MOC_LITERAL(11, 132, 9), // "entryInfo"
QT_MOC_LITERAL(12, 142, 17), // "slotDisableAction"
QT_MOC_LITERAL(13, 160, 11), // "slotChanged"
QT_MOC_LITERAL(14, 172, 16), // "launchcb_clicked"
QT_MOC_LITERAL(15, 189, 14), // "termcb_clicked"
QT_MOC_LITERAL(16, 204, 13), // "uidcb_clicked"
QT_MOC_LITERAL(17, 218, 23), // "slotCapturedKeySequence"
QT_MOC_LITERAL(18, 242, 16), // "slotExecSelected"
QT_MOC_LITERAL(19, 259, 18), // "onlyshowcb_clicked"
QT_MOC_LITERAL(20, 278, 21) // "hiddenentrycb_clicked"

    },
    "BasicTab\0changed\0\0MenuFolderInfo*\0"
    "MenuEntryInfo*\0findServiceShortcut\0"
    "KShortcut\0KService::Ptr&\0setFolderInfo\0"
    "folderInfo\0setEntryInfo\0entryInfo\0"
    "slotDisableAction\0slotChanged\0"
    "launchcb_clicked\0termcb_clicked\0"
    "uidcb_clicked\0slotCapturedKeySequence\0"
    "slotExecSelected\0onlyshowcb_clicked\0"
    "hiddenentrycb_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BasicTab[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       1,    1,   87,    2, 0x06 /* Public */,
       5,    2,   90,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   95,    2, 0x0a /* Public */,
      10,    1,   98,    2, 0x0a /* Public */,
      12,    0,  101,    2, 0x0a /* Public */,
      13,    0,  102,    2, 0x09 /* Protected */,
      14,    0,  103,    2, 0x09 /* Protected */,
      15,    0,  104,    2, 0x09 /* Protected */,
      16,    0,  105,    2, 0x09 /* Protected */,
      17,    1,  106,    2, 0x09 /* Protected */,
      18,    0,  109,    2, 0x09 /* Protected */,
      19,    0,  110,    2, 0x09 /* Protected */,
      20,    0,  111,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 7,    2,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    9,
    QMetaType::Void, 0x80000000 | 4,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QKeySequence,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void BasicTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BasicTab *_t = static_cast<BasicTab *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->changed((*reinterpret_cast< MenuFolderInfo*(*)>(_a[1]))); break;
        case 1: _t->changed((*reinterpret_cast< MenuEntryInfo*(*)>(_a[1]))); break;
        case 2: _t->findServiceShortcut((*reinterpret_cast< const KShortcut(*)>(_a[1])),(*reinterpret_cast< KService::Ptr(*)>(_a[2]))); break;
        case 3: _t->setFolderInfo((*reinterpret_cast< MenuFolderInfo*(*)>(_a[1]))); break;
        case 4: _t->setEntryInfo((*reinterpret_cast< MenuEntryInfo*(*)>(_a[1]))); break;
        case 5: _t->slotDisableAction(); break;
        case 6: _t->slotChanged(); break;
        case 7: _t->launchcb_clicked(); break;
        case 8: _t->termcb_clicked(); break;
        case 9: _t->uidcb_clicked(); break;
        case 10: _t->slotCapturedKeySequence((*reinterpret_cast< const QKeySequence(*)>(_a[1]))); break;
        case 11: _t->slotExecSelected(); break;
        case 12: _t->onlyshowcb_clicked(); break;
        case 13: _t->hiddenentrycb_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KShortcut >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (BasicTab::*_t)(MenuFolderInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicTab::changed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (BasicTab::*_t)(MenuEntryInfo * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicTab::changed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (BasicTab::*_t)(const KShortcut & , KService::Ptr & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicTab::findServiceShortcut)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject BasicTab::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_BasicTab.data,
      qt_meta_data_BasicTab,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *BasicTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BasicTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BasicTab.stringdata0))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int BasicTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void BasicTab::changed(MenuFolderInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void BasicTab::changed(MenuEntryInfo * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void BasicTab::findServiceShortcut(const KShortcut & _t1, KService::Ptr & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
