/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p khotkeys_interface /usr/share/dbus-1/interfaces/org.kde.khotkeys.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KHOTKEYS_INTERFACE_H
#define KHOTKEYS_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.khotkeys
 */
class OrgKdeKhotkeysInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.khotkeys"; }

public:
    OrgKdeKhotkeysInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKhotkeysInterface();

public Q_SLOTS: // METHODS
    inline Q_NOREPLY void declareConfigOutdated()
    {
        QList<QVariant> argumentList;
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("declareConfigOutdated"), argumentList);
    }

    inline QDBusPendingReply<QString> get_menuentry_shortcut(const QString &storageId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(storageId);
        return asyncCallWithArgumentList(QStringLiteral("get_menuentry_shortcut"), argumentList);
    }

    inline Q_NOREPLY void quit()
    {
        QList<QVariant> argumentList;
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("quit"), argumentList);
    }

    inline QDBusPendingReply<QString> register_menuentry_shortcut(const QString &storageId, const QString &sequence)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(storageId) << QVariant::fromValue(sequence);
        return asyncCallWithArgumentList(QStringLiteral("register_menuentry_shortcut"), argumentList);
    }

    inline Q_NOREPLY void reread_configuration()
    {
        QList<QVariant> argumentList;
        callWithArgumentList(QDBus::NoBlock, QStringLiteral("reread_configuration"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    typedef ::OrgKdeKhotkeysInterface khotkeys;
  }
}
#endif
